aboutsummaryrefslogtreecommitdiffstats
path: root/actionview
diff options
context:
space:
mode:
authorschneems <richard.schneeman@gmail.com>2016-08-30 15:02:56 -0500
committerschneems <richard.schneeman@gmail.com>2016-08-30 15:02:56 -0500
commitab5857a53a50cf9de0a8b869c5f43b1acdb90aa5 (patch)
tree0f098b0951d93836a12865584f6ce19d5acf009b /actionview
parent3ee9d0061fa042a9fcffa864ffa1492a00d0d179 (diff)
downloadrails-ab5857a53a50cf9de0a8b869c5f43b1acdb90aa5.tar.gz
rails-ab5857a53a50cf9de0a8b869c5f43b1acdb90aa5.tar.bz2
rails-ab5857a53a50cf9de0a8b869c5f43b1acdb90aa5.zip
Better keyword argument name
Diffstat (limited to 'actionview')
-rw-r--r--actionview/lib/action_view/helpers/asset_tag_helper.rb6
1 files changed, 3 insertions, 3 deletions
diff --git a/actionview/lib/action_view/helpers/asset_tag_helper.rb b/actionview/lib/action_view/helpers/asset_tag_helper.rb
index 9c22fb0bde..2b9c1a8ceb 100644
--- a/actionview/lib/action_view/helpers/asset_tag_helper.rb
+++ b/actionview/lib/action_view/helpers/asset_tag_helper.rb
@@ -257,7 +257,7 @@ module ActionView
# * <tt>:size</tt> - Supplied as "{Width}x{Height}" or "{Number}", so "30x45" becomes
# width="30" and height="45", and "50" becomes width="50" and height="50".
# <tt>:size</tt> will be ignored if the value is not in the correct format.
# * <tt>:public_poster_folder</tt> will bypass the asset pipeline when using
# the <tt>:poster</tt> option instead using an asset in the public folder.
#
# ==== Examples
@@ -270,7 +270,7 @@ module ActionView
# # => <video preload="none" controls="controls" src="/videos/trailer.ogg" ></video>
# video_tag("trailer.m4v", size: "16x10", poster: "screenshot.png")
# # => <video src="/videos/trailer.m4v" width="16" height="10" poster="/assets/screenshot.png"></video>
- # video_tag("trailer.m4v", size: "16x10", poster: "screenshot.png", public_poster_folder: true)
+ # video_tag("trailer.m4v", size: "16x10", poster: "screenshot.png", poster_skip_pipeline: true)
# # => <video src="/videos/trailer.m4v" width="16" height="10" poster="screenshot.png"></video>
# video_tag("/trailers/hd.avi", size: "16x16")
# # => <video src="/trailers/hd.avi" width="16" height="16"></video>
@@ -286,7 +286,7 @@ module ActionView
# # => <video height="120" width="160"><source src="/videos/trailer.ogg" /><source src="/videos/trailer.flv" /></video>
def video_tag(*sources)
options = sources.extract_options!.symbolize_keys
- public_poster_folder = options.delete(:public_poster_folder)
+ public_poster_folder = options.delete(:poster_skip_pipeline)
sources << options
multiple_sources_tag_builder("video", sources) do |options|
options[:poster] = path_to_image(options[:poster], skip_pipeline: public_poster_folder) if options[:poster]
@@ -257,7 +257,7 @@ module ActionView
# width="30" and height="45", and "50" becomes width="50" and height="50".
# <tt>:size</tt> will be ignored if the value is not in the correct format.
- # * <tt>:public_poster_folder</tt> will bypass the asset pipeline when using
+ # * <tt>:poster_skip_pipeline</tt> will bypass the asset pipeline when using
# the <tt>:poster</tt> option instead using an asset in the public folder.
#